@@ -1,7 +1,4 @@
-from typing import Optional
-
-
 class JobsException(Exception):
-    def __init__(self, job_id: str, msg: [Optional[str]] = None):
+    def __init__(self, job_id, msg=None):
         self.job_id = job_id
         super().__init__(msg)
