@@ -1,4 +1,4 @@
-from unittest import mock
+from .compat import mock
 
 
 class MockResponse:
