@@ -109,15 +109,16 @@ class JobsSdk:
             items=items,
         )
 
-    def download_job_results(self, job_id, path):
+    def download_job_results(self, job_id, path, nonce=None):
         """
         Download your job results when job is completed
 
         :param job_id: str
         :param path: str: path to directory, where results will be saved
+        :param nonce: str: can still download the file if provide an auth token
         :return: List[str]: list of filenames that were downloaded
         """
-        return self._jobs_service.download_job_results(job_id, path)
+        return self._jobs_service.download_job_results(job_id, path, nonce)
 
     def update_job(self, request):
         """ Updates an existing job
